#!/usr/bin/perl -w

# Copyright 2021 Kevin Ryde
#
# This file is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 3, or (at your option) any later
# version.
#
# This file is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License along
# with this file.  If not, see <http://www.gnu.org/licenses/>.

use 5.010;
use strict;
use warnings;
use File::Spec;

use FindBin;
use lib $FindBin::Bin;
use MyAppendMorphism '@LtoH_state_table',
  '@LtoH_state_to_name','$LtoH_max_state';
use MyFLAT;

print "% generated by tools/$FindBin::Script\n";

print "% GP-DEFINE  \\\\ like a073057-code.gp but including states S,T,U\n";
print "% GP-DEFINE  LtoH_state_table_full = {[\n";
foreach my $from (1 .. $LtoH_max_state) {
  my $row = $LtoH_state_table[$from];
  my $row_str = join(',',@$row) . ($from==$LtoH_max_state ? '' : ';');
  if (my $from_name = $LtoH_state_to_name[$from]) {
    printf "%% GP-DEFINE    %-8s  \\\\ %2d   %s -> %s\n",
      $row_str, $from, $from_name, join(',',map {$LtoH_state_to_name[$_]} @$row);
  } else {
    printf "%% GP-DEFINE    %-8s  \\\\ %2d unused\n", $row_str, $from;
  }
}
print "% GP-DEFINE  ]};\n";

foreach my $state (1 .. $LtoH_max_state) {
  my $name = $LtoH_state_to_name[$state];
  if ($name) {
    print "% GP-DEFINE  LtoH_state_$name = $state;\n";
  }
}

print "% end generated\n";
exit 0;
